@@ -182,13 +182,14 @@ EnsembleErrorProc(
     Tcl_Interp *interp,
     Tcl_Obj *procNameObj)
 {
-    int overflow, limit = 60, nameLen;
+    int overflow, limit = 60;
+    Tcl_Size nameLen;
     const char *procName = Tcl_GetStringFromObj(procNameObj, &nameLen);
 
-    overflow = (nameLen > limit);
+    overflow = (nameLen > (Tcl_Size)limit);
     Tcl_AppendObjToErrorInfo(interp, Tcl_ObjPrintf(
             "\n    (itcl ensemble part \"%.*s%s\" line %d)",
-            (overflow ? limit : nameLen), procName,
+            (overflow ? limit : (int)nameLen), procName,
             (overflow ? "..." : ""), Tcl_GetErrorLine(interp)));
 }
 
@@ -198,7 +199,7 @@ Itcl_InvokeEnsembleMethod(
     Tcl_Namespace *nsPtr,       /* namespace to call the method in */
     Tcl_Obj *namePtr,           /* name of the method */
     Tcl_Proc *procPtr,
-    size_t objc,			/* Number of arguments. */
+    Tcl_Size objc,			/* Number of arguments. */
     Tcl_Obj *const *objv)	/* Arguments as actually seen. */
 {
     ProcedureMethod *pmPtr = (ProcedureMethod *)ckalloc(sizeof(ProcedureMethod));
@@ -232,7 +233,7 @@ Itcl_PublicObjectCmd(
     void *clientData,
     Tcl_Interp *interp,
     Tcl_Class clsPtr,
-    size_t objc,
+    Tcl_Size objc,
     Tcl_Obj *const *objv)
 {
     Tcl_Object oPtr = (Tcl_Object)clientData;
